Enum MpvNodeValue
Source pub enum MpvNodeValue<'a> {
String(&'a str),
Flag(bool),
Int64(i64),
Double(f64),
Array(MpvNodeArrayIter<'a>),
Map(MpvNodeMapIter<'a>),
None,
}
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.